@@ -44,7 +44,7 @@ pango_ot_ruleset_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       const GTypeInfo object_info =
       {
@@ -80,6 +80,10 @@ static void
 pango_ot_ruleset_init (PangoOTRuleset *ruleset)
 {
   ruleset->rules = g_array_new (FALSE, FALSE, sizeof (PangoOTRule));
+  ruleset->script_index[0]   = PANGO_OT_NO_SCRIPT;
+  ruleset->script_index[1]   = PANGO_OT_NO_SCRIPT;
+  ruleset->language_index[0] = PANGO_OT_DEFAULT_LANGUAGE;
+  ruleset->language_index[1] = PANGO_OT_DEFAULT_LANGUAGE;
 }
 
 static void
@@ -112,7 +116,7 @@ pango_ot_ruleset_finalize (GObject *object)
  *
  * Since: 1.18
  **/
-const PangoOTRuleset *
+G_CONST_RETURN PangoOTRuleset *
 pango_ot_ruleset_get_for_description (PangoOTInfo                     *info,
 				      const PangoOTRulesetDescription *desc)
 {
@@ -173,11 +177,6 @@ pango_ot_ruleset_new (PangoOTInfo *info)
   ruleset->info = info;
   g_object_add_weak_pointer (ruleset->info, &ruleset->info);
 
-  ruleset->script_index[0]   = PANGO_OT_NO_SCRIPT;
-  ruleset->script_index[1]   = PANGO_OT_NO_SCRIPT;
-  ruleset->language_index[0] = PANGO_OT_DEFAULT_LANGUAGE;
-  ruleset->language_index[1] = PANGO_OT_DEFAULT_LANGUAGE;
-
   return ruleset;
 }
 
